@@ -14,20 +14,15 @@
 
 #include "radselect.h"
 
-static const char version[] = "0.1";
-
 int main(int argc, char **argv)
 {
-    QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-    QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-
     QApplication app(argc, argv);
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("kiten"), app.windowIcon()));
     KLocalizedString::setApplicationDomain("kiten");
 
     KAboutData about(QStringLiteral("kitenradselect"),
                      i18n("Radical Selector"),
-                     version,
+                     QStringLiteral("0.1"),
                      i18n("A KDE Application"),
                      KAboutLicense::GPL,
                      i18n("(C) 2005 Joseph Kerian"),
